==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/UseCaseParticipantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.InteractionParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.UseCaseParticipant;
import io.ciera.tool.sql.ooaofooa.interaction.UseCaseParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InteractionParticipantSetImpl;

import java.util.Arrays;
import java.util.List;


public class UseCaseParticipantSetImpl extends InstanceSet<UseCaseParticipantSet,UseCaseParticipant> implements UseCaseParticipantSet {

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( UseCaseParticipant usecaseparticipant : this ) usecaseparticipant.setDescrip( m_Descrip );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( UseCaseParticipant usecaseparticipant : this ) usecaseparticipant.setName( m_Name );
    }
    @Override
    public void setPart_ID( UniqueId ref_Part_ID ) throws XtumlException {
        for ( UseCaseParticipant usecaseparticipant : this ) usecaseparticipant.setPart_ID( ref_Part_ID );
    }


    // selections
    @Override
    public InteractionParticipantSet R930_is_a_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( UseCaseParticipant usecaseparticipant : this ) interactionparticipantset.add( usecaseparticipant.R930_is_a_InteractionParticipant() );
        return interactionparticipantset;
    }


    @Override
    public UseCaseParticipant nullElement() {
        return UseCaseParticipantImpl.EMPTY_USECASEPARTICIPANT;
    }

    @Override
    public UseCaseParticipantSet emptySet() {
      return new UseCaseParticipantSetImpl();
    }

    @Override
    public UseCaseParticipantSet value() {
        return this;
    }

    @Override
    public List<UseCaseParticipant> elements() {
        UseCaseParticipant[] elements = toArray(new UseCaseParticipant[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/UseCaseParticipantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.InteractionParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.UseCaseParticipant;
import io.ciera.tool.sql.ooaofooa.interaction.UseCaseParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InteractionParticipantSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class UseCaseParticipantSetImpl extends InstanceSet<UseCaseParticipantSet,UseCaseParticipant> implements UseCaseParticipantSet {

    public UseCaseParticipantSetImpl() {
    }

    public UseCaseParticipantSetImpl(Comparator<? super UseCaseParticipant> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setPart_ID( UniqueId ref_Part_ID ) throws XtumlException {
        for ( UseCaseParticipant usecaseparticipant : this ) usecaseparticipant.setPart_ID( ref_Part_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( UseCaseParticipant usecaseparticipant : this ) usecaseparticipant.setDescrip( m_Descrip );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( UseCaseParticipant usecaseparticipant : this ) usecaseparticipant.setName( m_Name );
    }


    // selections
    @Override
    public InteractionParticipantSet R930_is_a_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( UseCaseParticipant usecaseparticipant : this ) interactionparticipantset.add( usecaseparticipant.R930_is_a_InteractionParticipant() );
        return interactionparticipantset;
    }


    @Override
    public UseCaseParticipant nullElement() {
        return UseCaseParticipantImpl.EMPTY_USECASEPARTICIPANT;
    }

    @Override
    public UseCaseParticipantSet emptySet() {
      return new UseCaseParticipantSetImpl();
    }

    @Override
    public UseCaseParticipantSet emptySet(Comparator<? super UseCaseParticipant> comp) {
      return new UseCaseParticipantSetImpl(comp);
    }

    @Override
    public UseCaseParticipantSet value() {
        return this;
    }

    @Override
    public List<UseCaseParticipant> elements() {
        UseCaseParticipant[] elements = toArray(new UseCaseParticipant[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
